==> apache-cxf-3.1.17-src.zip: apache-cxf-3.1.17-src/core/src/main/java/org/apache/cxf/bus/CXFBusFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.bus;

import java.util.HashMap;
import java.util.Map;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.bus.extension.ExtensionManagerBus;

public class CXFBusFactory extends BusFactory {
    
    public Bus createBus() {
        return createBus(new HashMap<Class<?>, Object>());
    }
    
    public Bus createBus(Map<Class<?>, Object> e) {
        return createBus(e, new HashMap<String, Object>());
    }
    
    public Bus createBus(Map<Class<?>, Object> e, Map<String, Object> properties) {
        ExtensionManagerBus bus = new ExtensionManagerBus(e, properties);
        possiblySetDefaultBus(bus);
        initializeBus(bus);
        bus.initialize();
        return bus;
    }
 
}

==> apache-cxf-3.6.9-src.zip: apache-cxf-3.6.9-src/core/src/main/java/org/apache/cxf/bus/CXFBusFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.bus;

import java.util.HashMap;
import java.util.Map;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.bus.extension.ExtensionManagerBus;

public class CXFBusFactory extends BusFactory {

    public Bus createBus() {
        return createBus(new HashMap<>());
    }

    public Bus createBus(Map<Class<?>, Object> e) {
        return createBus(e, new HashMap<>());
    }

    public Bus createBus(Map<Class<?>, Object> e, Map<String, Object> properties) {
        ExtensionManagerBus bus = new ExtensionManagerBus(e, properties);
        possiblySetDefaultBus(bus);
        initializeBus(bus);
        bus.initialize();
        return bus;
    }

}
